@@ -6,7 +6,7 @@ use 5.008001;
 use Carp qw( croak );
 
 # ABSTRACT: Write Perl bindings to non-Perl libraries with FFI. No XS required.
-our $VERSION = '0.49_05'; # TRIAL VERSION
+our $VERSION = '0.52_01'; # TRIAL VERSION
 
 # Platypus Man,
 # Platypus Man,
@@ -423,14 +423,14 @@ sub find_symbol
 
   foreach my $path (@{ $self->{lib} })
   {
-    my $handle = do { no warnings; $self->{handles}->{$path||0} } || FFI::Platypus::dl::dlopen($path);
+    my $handle = do { no warnings; $self->{handles}->{$path||0} } || FFI::Platypus::DL::dlopen($path, FFI::Platypus::DL::RTLD_DEFAULT());
     unless($handle)
     {
-      warn "error loading $path: ", FFI::Platypus::dl::dlerror()
+      warn "error loading $path: ", FFI::Platypus::DL::dlerror()
         if $ENV{FFI_PLATYPUS_DLERROR};
       next;
     }
-    my $address = FFI::Platypus::dl::dlsym($handle, $self->{mangler}->($name));
+    my $address = FFI::Platypus::DL::dlsym($handle, $self->{mangler}->($name));
     if($address)
     {
       $self->{handles}->{$path||0} = $handle;
@@ -438,7 +438,7 @@ sub find_symbol
     }
     else
     {
-      FFI::Platypus::dl::dlclose($handle) unless $self->{handles}->{$path||0};
+      FFI::Platypus::DL::dlclose($handle) unless $self->{handles}->{$path||0};
     }
   }
   return;
@@ -449,16 +449,37 @@ sub package
 {
   my($self, $module, $modlibname) = @_;
 
-  require FFI::Platypus::ShareConfig;  
-  my @dlext = @{ FFI::Platypus::ShareConfig->get("config_dlext") };
-
   ($module, $modlibname) = caller() unless defined $modlibname;  
   my @modparts = split /::/, $module;
   my $modfname = $modparts[-1];
   my $modpname = join('/',@modparts);
   my $c = @modparts;
   $modlibname =~ s,[\\/][^\\/]+$,, while $c--;    # Q&D basename
+
+  {
+    my @maybe = (
+      "$modlibname/auto/$modpname/$modfname.txt",
+      "$modlibname/../arch/auto/$modpname/$modfname.txt",
+    );
+    foreach my $file (@maybe)
+    {
+      if(-f $file)
+      {
+        open my $fh, '<', $file;
+        my $line = <$fh>;
+        close $fh;
+        if($line =~ /^FFI::Build\@(.*)$/)
+        {
+          $self->lib("$modlibname/$1");
+          return $self;
+        }
+      }
+    }
+  }
   
+  require FFI::Platypus::ShareConfig;  
+  my @dlext = @{ FFI::Platypus::ShareConfig->get("config_dlext") };
+
   foreach my $dlext (@dlext)
   {
     my $file = "$modlibname/auto/$modpname/$modfname.$dlext";
@@ -514,7 +535,7 @@ sub DESTROY
   foreach my $handle (values %{ $self->{handles} })
   {
     next unless $handle;
-    FFI::Platypus::dl::dlclose($handle);
+    FFI::Platypus::DL::dlclose($handle);
   }
   delete $self->{handles};
 }
@@ -529,7 +550,7 @@ sub _have_pm
 
 package FFI::Platypus::Function;
 
-our $VERSION = '0.49_05'; # TRIAL VERSION
+our $VERSION = '0.52_01'; # TRIAL VERSION
 
 use overload '&{}' => sub {
   my $ffi = shift;
@@ -550,7 +571,7 @@ use overload '&{}' => sub {
   sub { $self->{code}->(@_) };
 };
 
-our $VERSION = '0.49_05'; # TRIAL VERSION
+our $VERSION = '0.52_01'; # TRIAL VERSION
 
 sub new
 {
@@ -579,13 +600,13 @@ sub get_data
 
 package FFI::Platypus::ClosureData;
 
-our $VERSION = '0.49_05'; # TRIAL VERSION
+our $VERSION = '0.52_01'; # TRIAL VERSION
 
 package FFI::Platypus::Type;
 
 use Carp qw( croak );
 
-our $VERSION = '0.49_05'; # TRIAL VERSION
+our $VERSION = '0.52_01'; # TRIAL VERSION
 
 sub new
 {
@@ -679,7 +700,7 @@ FFI::Platypus - Write Perl bindings to non-Perl libraries with FFI. No XS requir
 
 =head1 VERSION
 
-version 0.49_05
+version 0.52_01
 
 =head1 SYNOPSIS
 
@@ -1192,10 +1213,10 @@ includes the standard c library.
  use FFI::CheckLib;
  use FFI::Platypus;
  
- # NOTE: I ported this from the like named eg/notify.pl that came with FFI::Raw
- # and it seems to work most of the time, but also seems to SIGSEGV sometimes.
- # I saw the same behavior in the FFI::Raw version, and am not really familiar
- # with the libnotify API to say what is the cause.  Patches welcome to fix it.
+ # NOTE: I ported this from anoter Perl FFI library and it seems to work most
+ # of the time, but also seems to SIGSEGV sometimes.  I saw the same behavior
+ # in the old version, and am not really familiar with the libnotify API to
+ # say what is the cause.  Patches welcome to fix it.
  
  my $ffi = FFI::Platypus->new;
  $ffi->lib(find_lib_or_exit lib => 'notify');
@@ -2205,14 +2226,6 @@ This module can extract constants and other useful objects from C header
 files that may be relevant to an FFI application.  One downside is that 
 its use may require development packages to be installed.
 
-=item L<FFI::Raw>
-
-Alternate interface to libffi with fewer features.  It notably lacks the 
-ability to create real xsubs, which may make L<FFI::Platypus> much 
-faster.  Also lacking are pointers to native types, arrays and custom 
-types.  In its favor, it has been around for longer that Platypus, and 
-has been battle tested to some success.
-
 =item L<Win32::API>
 
 Microsoft Windows specific FFI style interface.
@@ -2260,10 +2273,9 @@ work on L<FFI::Sweet|https://github.com/merrilymeredith/p5-FFI-Sweet>
 not only helped me get started with FFI but significantly influenced the 
 design of Platypus.
 
-In addition I'd like to thank Alessandro Ghedini (ALEXBIO) who was 
-always responsive to bug reports and pull requests for L<FFI::Raw>, 
-which was important in the development of the ideas on which Platypus is 
-based.
+In addition I'd like to thank Alessandro Ghedini (ALEXBIO) whose work
+on another Perl FFI library helped drive some of the development ideas
+for L<FFI::Platypus>.
 
 =head1 AUTHOR
 
